@@ -6,10 +6,10 @@ Created on 2019-06-26 by kevincar <kevincarrolldavis@gmail.com>
 
 import logging
 import uuid
-from typing import Callable, Any, Union
+from typing import Callable, Union
 import asyncio
 
-from Foundation import NSData, CBUUID
+from Foundation import NSData
 from CoreBluetooth import (
     CBCharacteristicWriteWithResponse,
     CBCharacteristicWriteWithoutResponse,
@@ -48,9 +48,7 @@ class BleakClientCoreBluetooth(BaseBleakClient):
 
         if isinstance(address_or_ble_device, BLEDevice):
             self._device_info = address_or_ble_device.details
-            self._central_manager_delegate = address_or_ble_device.metadata.get(
-                "delegate"
-            )
+            self._central_manager_delegate = address_or_ble_device.metadata["delegate"]
         else:
             self._device_info = None
             self._central_manager_delegate = None
@@ -79,7 +77,7 @@ class BleakClientCoreBluetooth(BaseBleakClient):
 
             if device:
                 self._device_info = device.details
-                self._central_manager_delegate = device.metadata.get("delegate")
+                self._central_manager_delegate = device.metadata["delegate"]
             else:
                 raise BleakError(
                     "Device with address {} was not found".format(self.address)
@@ -122,7 +120,7 @@ class BleakClientCoreBluetooth(BaseBleakClient):
     async def is_connected(self) -> bool:
         """Checks for current active connection"""
         manager = self._central_manager_delegate
-        return manager.isConnected
+        return False if manager is None else manager.isConnected
 
     async def pair(self, *args, **kwargs) -> bool:
         """Attempt to pair with a peripheral.
