@@ -1,6 +1,9 @@
 # -*- coding: utf-8 -*-
 from bleak.backends.descriptor import BleakGATTDescriptor
 
+# Import of BleakBridge to enable loading of winrt bindings
+from BleakBridge import Bridge  # noqa: F401
+
 from Windows.Devices.Bluetooth.GenericAttributeProfile import GattDescriptor
 
 
